/***
 * FractalGUI: a graphical tool to edit Fractal component configurations.
 * Copyright (C) 2003 France Telecom R&D
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: fractal@objectweb.org
 *
 * Authors: Eric Bruneton, Patrice Fauvel
 */

package org.objectweb.fractal.gui.repository.api;

import org.objectweb.fractal.gui.graph.model.GraphModel;
import org.objectweb.fractal.gui.model.Component;

/**
 * A repository of component configuration definitions.
 */

public interface Repository {

  /**
   * Loads a component (and all its sub components) from this repository.
   *
   * @param name the name of the component to be loaded.
   * @param graph an optional graph model.
   * @return the loaded component.
   * @throws Exception if the component cannot loaded.
   */

  Component loadComponent (String name, GraphModel graph) throws Exception;

  /**
   * Stores a component (and all its sub components) into this repository.
   *
   * @param component the component to be stored.
   * @param graph an optional graph model.
   * @param hints options.
   * @return the name of the component that has been stored.
   * @throws Exception if the component cannot be stored.
   */
  
  String storeComponent (Component component, GraphModel graph, Object hints) 
    throws Exception;
}
